# The original code for the library is here
https://github.com/dandynaufaldi/particle-swarm-optimized-clustering

# install
  `pip install swarmk`
  
#use
```python
import swarmk as sw
```

or

```python
from swarmk.pso import ParticleSwarmOptimizedClustering
from swarmk.particle import quantization_error, calc_sse
from swarmk.utils import normalize
from swarmk.kmeans import KMeans
```
